***********************************************
* LABOR MARKET IMPACT OF TECHNOLOGY AND TRADE
***********************************************

* David Dorn, December 12, 2011
* Updated September 10, 2012; October 19, 2012; August 22, 2013; April 13, 2014
* August 19, 2014: add OLS results and regression plots

* Input files: 
* - workfile_china.dta (from Autor, Dorn and Hanson, AER 2013)
* - workfile2012.dta (from Autor and Dorn, AER 2013)
* - czoneYYYYpor_current_v2.dta and czoneYYYYpor_mfg_v3.dta 
* (Czone-level variables on employment composition and routine share from Census/ACS, YYYY=1980, 1990, 2000, 060708)
* - czone1950por_indstr_v2.dta (prediction of routine share based on 1950 data)
* - cbp_mfgsh.dta (Czone manufacturing employment share according to County Business Patterns)


***********************************************
* Administrative Commands
***********************************************

cap log close                       
set more off                        
clear                               
set memory 500m                    


log using ../log/czone_analysis_untangling_final.log, replace text


***********************************************
* Data Preparation
***********************************************

* split main data file from Autor, Dorn and Hanson (AER 2013) by period
foreach y in 1990 2000 {
   use ../dta/workfile_china.dta, clear
   drop *routine*
   keep if yr==`y'
   sort czone
   save temp`y'.dta, replace
}

* use 1980-1990 period data from main file of Autor & Dorn (AER 2013)
use ../dta/workfile2012.dta, clear
keep if yr==1980
keep czone statefip timepwt48 yr 
sort czone 
save temp1980.dta, replace

* interact 1950 RSH instrument with years
foreach y in 1980 1990 2000 {
   use ../dta/czone1950por_indstr_v2.dta, clear	
   foreach k in _ _mfg_ _nmfg_ {
      quietly gen R33a`k'1950_`y'=R33a`k'ind
   }
   keep czone R33a*`y'
   sort czone
   save temp`y'rsh.dta, replace
}

* sort additional CZ data
foreach y in 1980 1990 2000 060708 {
   foreach k in current {
      use ../dta/czone`y'por_`k'_v2.dta, clear
	  sort czone
	  save ../dta/czone`y'por_`k'_v2.dta, replace
   }
   foreach k in mfg {
      use ../dta/czone`y'por_`k'_v3.dta, clear
	  sort czone
	  save ../dta/czone`y'por_`k'_v3.dta, replace
   }
}

* merge data separately by decade
foreach y in 1980 1990 2000 {
   use ../dta/czone`y'por_current_v2.dta, clear
   merge czone using ../dta/czone`y'por_mfg_v3.dta
   assert _merge==3
   drop _merge
   drop no_*
   foreach var of varlist sh_* {
      rename `var' l_`var'
   }
   sort czone
   if `y'==1980 merge czone using ../dta/czone1990por_current_v2.dta
   if `y'==1990 merge czone using ../dta/czone2000por_current_v2.dta
   if `y'==2000 merge czone using ../dta/czone060708por_current_v2.dta
   assert _merge==3
   drop _merge
   drop no_*
   foreach var of varlist sh_empl_* sh_unempl* sh_nilf* {
      quietly gen d_`var'=`var'-l_`var'
	  quietly replace d_`var'=10/7*d_`var' if `y'==2000
	  drop `var'
   }
   
   * define variables for employment in abstract, routine and manual occs (as in Autor and Dorn, AER 2013)
   foreach v in mpt ass prod trans othprod svc farmmin {
	  foreach k in l d {
         quietly gen `k'_sh_empl_`v'=`k'_sh_empl_mfg_`v'+`k'_sh_empl_nmfg_`v'
	  }
   }
   foreach v in empl empl_mfg empl_nmfg empl_male empl_female empl_nc empl_c empl_young empl_old {
	  foreach k in l d {
         quietly gen `k'_sh_`v'_ta=`k'_sh_`v'_mpt
         quietly gen `k'_sh_`v'_tr=`k'_sh_`v'_ass+`k'_sh_`v'_prod
         quietly gen `k'_sh_`v'_tm=`k'_sh_`v'_svc+`k'_sh_`v'_farmmin+`k'_sh_`v'_trans+`k'_sh_`v'_othprod
	  }
   }	   
   drop *nmfg2* *mpt* *trans* *othprod* *svc* *farmmin* *firepol* *mgmt* *ptf* *cleric* *rsales*
   sort czone
   merge czone using temp`y'.dta
   keep if _merge==3
   drop _merge
   sort czone
   merge czone using temp`y'rsh.dta
   keep if _merge==3
   drop _merge
   erase temp`y'.dta
   erase temp`y'rsh.dta
  
   sort czone
   save temp`y'.dta, replace
}

* construct stacked first differences file for periods 1990-2000, 2000-2007
use temp1990.dta, clear
append using temp2000.dta
erase temp1990.dta
erase temp2000.dta

* rename some variables
rename l_sh_routine33a l_sh_routine33
rename l_sh_routine33a_mfg l_sh_routine33_mfg
rename l_sh_routine33a_nmfg l_sh_routine33_nmfg
foreach k in _ _mfg_ _nmfg_ {
   rename R33a`k'1950_1990 R33a`k'1950_90
   rename R33a`k'1950_2000 R33a`k'1950_00
}

* set RSH interactions to zero except for interacted year
foreach var of varlist R33a_*1950* {
   quietly replace `var'=0 if `var'==.
}

* scaling of variables to percentage points
foreach var of varlist d_sh_empl_* d_sh_unemp* d_sh_nilf* l_shind_manuf_cbp l_sh_popedu_c l_sh_popfborn l_sh_empl_f l_sh_routine33* {
   quietly replace `var'=100*`var'
}


******************************************************************************************************************************************************************************************
* Descriptives
******************************************************************************************************************************************************************************************

* correlation between China shock and routine share
by yr, sort: pwcorr d_tradeusch_pw d_tradeotch_pw_lag l_sh_routine33 l_sh_routine33_mfg l_sh_routine33_nmfg [aw=timepwt48]
by yr, sort: summ d_tradeusch_pw d_tradeotch_pw_lag l_sh_routine33 l_sh_routine33_mfg l_sh_routine33_nmfg [aw=timepwt48], detail

* share of working age population by sector-occupation cells
summ l_sh_empl l_sh_empl_ta l_sh_empl_tr l_sh_empl_tm [aw=timepwt48] if yr==1990
summ l_sh_empl_mfg l_sh_empl_mfg_ta l_sh_empl_mfg_tr l_sh_empl_mfg_tm [aw=timepwt48] if yr==1990
summ l_sh_empl_nmfg l_sh_empl_nmfg_ta l_sh_empl_nmfg_tr l_sh_empl_nmfg_tm [aw=timepwt48] if yr==1990



******************************************************************************************************************************************************************************************
* Regression Analysis, 1990-2000/2000-2007
******************************************************************************************************************************************************************************************


*** TABLE 1-2 - Employment, Unemployment and Non-Employment, Overall and By Subsample ***

foreach k in empl unempl nilf {
   ivregress 2sls d_sh_`k' (d_tradeusch_pw=d_tradeotch_pw_lag) l_shind_manuf_cbp reg* l_sh_popedu_c l_sh_popfborn l_sh_empl_f t2 [aw=timepwt48], cluster(statefip)
   ivregress 2sls d_sh_`k' (l_sh_routine33=R33a_1950_90 R33a_1950_00) l_shind_manuf_cbp reg* l_sh_popedu_c l_sh_popfborn l_sh_empl_f t2 [aw=timepwt48], cluster(statefip)
   ivregress 2sls d_sh_`k' (d_tradeusch_pw l_sh_routine33=d_tradeotch_pw_lag R33a_1950_90 R33a_1950_00) l_shind_manuf_cbp reg* l_sh_popedu_c l_sh_popfborn l_sh_empl_f t2 [aw=timepwt48], cluster(statefip)
foreach v in male female nc c young old {
   ivregress 2sls d_sh_`k'_`v' (d_tradeusch_pw l_sh_routine33=d_tradeotch_pw_lag R33a_1950_90 R33a_1950_00) l_shind_manuf_cbp reg* l_sh_popedu_c l_sh_popfborn l_sh_empl_f t2 [aw=timepwt48], cluster(statefip)
}
}

* APPENDIX TABLE 1 - OLS Results
reg d_sh_empl d_tradeusch_pw l_sh_routine33 l_shind_manuf_cbp reg* l_sh_popedu_c l_sh_popfborn l_sh_empl_f t2 [aw=timepwt48], cluster(statefip)
reg d_sh_unempl d_tradeusch_pw l_sh_routine33 l_shind_manuf_cbp reg* l_sh_popedu_c l_sh_popfborn l_sh_empl_f t2 [aw=timepwt48], cluster(statefip)
reg d_sh_nilf d_tradeusch_pw l_sh_routine33 l_shind_manuf_cbp reg* l_sh_popedu_c l_sh_popfborn l_sh_empl_f t2 [aw=timepwt48], cluster(statefip)

*** TABLE 3 - Employment by Occ Group, Overall and By Subsample ***

foreach k in ta tr tm {
ivregress 2sls d_sh_empl_`k' (d_tradeusch_pw l_sh_routine33=d_tradeotch_pw_lag R33a_1950_90 R33a_1950_00) l_shind_manuf_cbp reg* l_sh_popedu_c l_sh_popfborn l_sh_empl_f t2 [aw=timepwt48], cluster(statefip)
foreach v in male female nc c young old {
   ivregress 2sls d_sh_empl_`v'_`k' (d_tradeusch_pw l_sh_routine33=d_tradeotch_pw_lag R33a_1950_90 R33a_1950_00) l_shind_manuf_cbp reg* l_sh_popedu_c l_sh_popfborn l_sh_empl_f t2 [aw=timepwt48], cluster(statefip)
   }
}

*** TABLE 4: China vs. Routinization, Mfg vs NMfg ***

ivregress 2sls d_sh_empl_mfg (d_tradeusch_pw l_sh_routine33_mfg=d_tradeotch_pw_lag R33a_mfg_1950_90 R33a_mfg_1950_00) l_shind_manuf_cbp reg* l_sh_popedu_c l_sh_popfborn l_sh_empl_f t2 [aw=timepwt48], cluster(statefip)
ivregress 2sls d_sh_empl_mfg_ta (d_tradeusch_pw l_sh_routine33_mfg=d_tradeotch_pw_lag R33a_mfg_1950_90 R33a_mfg_1950_00) l_shind_manuf_cbp reg* l_sh_popedu_c l_sh_popfborn l_sh_empl_f t2 [aw=timepwt48], cluster(statefip)
ivregress 2sls d_sh_empl_mfg_tr (d_tradeusch_pw l_sh_routine33_mfg=d_tradeotch_pw_lag R33a_mfg_1950_90 R33a_mfg_1950_00) l_shind_manuf_cbp reg* l_sh_popedu_c l_sh_popfborn l_sh_empl_f t2 [aw=timepwt48], cluster(statefip)
ivregress 2sls d_sh_empl_mfg_tm (d_tradeusch_pw l_sh_routine33_mfg=d_tradeotch_pw_lag R33a_mfg_1950_90 R33a_mfg_1950_00) l_shind_manuf_cbp reg* l_sh_popedu_c l_sh_popfborn l_sh_empl_f t2 [aw=timepwt48], cluster(statefip)

ivregress 2sls d_sh_empl_mfg_ass (d_tradeusch_pw l_sh_routine33_mfg=d_tradeotch_pw_lag R33a_mfg_1950_90 R33a_mfg_1950_00) l_shind_manuf_cbp reg* l_sh_popedu_c l_sh_popfborn l_sh_empl_f t2 [aw=timepwt48], cluster(statefip)
ivregress 2sls d_sh_empl_mfg_prod (d_tradeusch_pw l_sh_routine33_mfg=d_tradeotch_pw_lag R33a_mfg_1950_90 R33a_mfg_1950_00) l_shind_manuf_cbp reg* l_sh_popedu_c l_sh_popfborn l_sh_empl_f t2 [aw=timepwt48], cluster(statefip)

ivregress 2sls d_sh_empl_nmfg (d_tradeusch_pw l_sh_routine33_nmfg=d_tradeotch_pw_lag R33a_nmfg_1950_90 R33a_nmfg_1950_00) l_shind_manuf_cbp reg* l_sh_popedu_c l_sh_popfborn l_sh_empl_f t2 [aw=timepwt48], cluster(statefip)
ivregress 2sls d_sh_empl_nmfg_ta (d_tradeusch_pw l_sh_routine33_nmfg=d_tradeotch_pw_lag R33a_nmfg_1950_90 R33a_nmfg_1950_00) l_shind_manuf_cbp reg* l_sh_popedu_c l_sh_popfborn l_sh_empl_f t2 [aw=timepwt48], cluster(statefip)
ivregress 2sls d_sh_empl_nmfg_tr (d_tradeusch_pw l_sh_routine33_nmfg=d_tradeotch_pw_lag R33a_nmfg_1950_90 R33a_nmfg_1950_00) l_shind_manuf_cbp reg* l_sh_popedu_c l_sh_popfborn l_sh_empl_f t2 [aw=timepwt48], cluster(statefip)
ivregress 2sls d_sh_empl_nmfg_tm (d_tradeusch_pw l_sh_routine33_nmfg=d_tradeotch_pw_lag R33a_nmfg_1950_90 R33a_nmfg_1950_00) l_shind_manuf_cbp reg* l_sh_popedu_c l_sh_popfborn l_sh_empl_f t2 [aw=timepwt48], cluster(statefip)



******************************************************************************************************************************************************************************************
* Regression Analysis, 1980-1990/1990-2000/2000-2007
******************************************************************************************************************************************************************************************

save temp.dta, replace

* prepare extended data set: 1980 CBP mfg share
use ../dta/cbp_mfgsh.dta, clear
keep if yr==1980
keep czone l_shind_manuf_cbp
sort czone
merge czone using temp1980.dta
keep if _merge==3
drop _merge 
erase temp1980.dta

* rename some variables
rename l_sh_routine33a l_sh_routine33
rename l_sh_routine33a_mfg l_sh_routine33_mfg
rename l_sh_routine33a_nmfg l_sh_routine33_nmfg
foreach k in _ _mfg_ _nmfg_ {
   rename R33a`k'1950_1980 R33a`k'1950_80
}

* set RSH interactions to zero except for interacted year
foreach var of varlist R33a_*1950* {
   replace `var'=0 if `var'==.
}

* scale variables to percentage points
foreach var of varlist d_sh_empl* l_sh_routine33 R33a_1950_80 l_sh_routine33_mfg R33a_mfg_1950_80 l_sh_routine33_nmfg R33a_nmfg_1950_80 l_shind_manuf_cbp {
   replace `var'=100*`var' if yr==1980
}

* append to main file
append using temp.dta
erase temp.dta

* create region dummies in 1980s
foreach var of varlist reg* {
   by czone, sort: egen max_`var'=max(`var')
   replace `var'=max_`var' if `var'==.
   drop max_`var'
}

* summary stats
summ d_sh_empl l_sh_routine33 R33a_1950_80 l_sh_routine33_mfg R33a_mfg_1950_80 l_sh_routine33_nmfg R33a_nmfg_1950_80 l_shind_manuf_cbp reg* statefip [aw=timepwt48] if yr==1980
summ l_sh_routine33_mfg l_sh_routine33_nmfg [aw=timepwt48] if yr==1980, detail


*** TABLE 5: China vs. Routinization, 1980s (no trade exposure)

ivregress 2sls d_sh_empl_mfg_ta (l_sh_routine33_mfg=R33a_mfg_1950_80) l_shind_manuf_cbp reg* [aw=timepwt48] if yr==1980, cluster(statefip)
ivregress 2sls d_sh_empl_mfg_tr (l_sh_routine33_mfg=R33a_mfg_1950_80) l_shind_manuf_cbp reg* [aw=timepwt48] if yr==1980, cluster(statefip)
ivregress 2sls d_sh_empl_mfg_tm (l_sh_routine33_mfg=R33a_mfg_1950_80) l_shind_manuf_cbp reg* [aw=timepwt48] if yr==1980, cluster(statefip)

ivregress 2sls d_sh_empl_mfg_ass (l_sh_routine33_mfg=R33a_mfg_1950_80) l_shind_manuf_cbp reg* [aw=timepwt48] if yr==1980, cluster(statefip)
ivregress 2sls d_sh_empl_mfg_prod (l_sh_routine33_mfg=R33a_mfg_1950_80) l_shind_manuf_cbp reg* [aw=timepwt48] if yr==1980, cluster(statefip)

ivregress 2sls d_sh_empl_nmfg_ta (l_sh_routine33_nmfg=R33a_nmfg_1950_80) l_shind_manuf_cbp reg* [aw=timepwt48] if yr==1980, cluster(statefip)
ivregress 2sls d_sh_empl_nmfg_tr (l_sh_routine33_nmfg=R33a_nmfg_1950_80) l_shind_manuf_cbp reg* [aw=timepwt48] if yr==1980, cluster(statefip)
ivregress 2sls d_sh_empl_nmfg_tm (l_sh_routine33_nmfg=R33a_nmfg_1950_80) l_shind_manuf_cbp reg* [aw=timepwt48] if yr==1980, cluster(statefip)


*** TABLE 5: China vs. Routinization, 1990s 

ivregress 2sls d_sh_empl_mfg_ta (d_tradeusch_pw l_sh_routine33_mfg=d_tradeotch_pw_lag R33a_mfg_1950_90) l_shind_manuf_cbp reg* [aw=timepwt48] if yr==1990, cluster(statefip)
ivregress 2sls d_sh_empl_mfg_tr (d_tradeusch_pw l_sh_routine33_mfg=d_tradeotch_pw_lag R33a_mfg_1950_90) l_shind_manuf_cbp reg* [aw=timepwt48] if yr==1990, cluster(statefip)
ivregress 2sls d_sh_empl_mfg_tm (d_tradeusch_pw l_sh_routine33_mfg=d_tradeotch_pw_lag R33a_mfg_1950_90) l_shind_manuf_cbp reg* [aw=timepwt48] if yr==1990, cluster(statefip)

ivregress 2sls d_sh_empl_mfg_ass (d_tradeusch_pw l_sh_routine33_mfg=d_tradeotch_pw_lag R33a_mfg_1950_90) l_shind_manuf_cbp reg* [aw=timepwt48] if yr==1990, cluster(statefip)
ivregress 2sls d_sh_empl_mfg_prod (d_tradeusch_pw l_sh_routine33_mfg=d_tradeotch_pw_lag R33a_mfg_1950_90) l_shind_manuf_cbp reg* [aw=timepwt48] if yr==1990, cluster(statefip)

ivregress 2sls d_sh_empl_nmfg_ta (d_tradeusch_pw l_sh_routine33_nmfg=d_tradeotch_pw_lag R33a_nmfg_1950_90) l_shind_manuf_cbp reg* [aw=timepwt48] if yr==1990, cluster(statefip)
ivregress 2sls d_sh_empl_nmfg_tr (d_tradeusch_pw l_sh_routine33_nmfg=d_tradeotch_pw_lag R33a_nmfg_1950_90) l_shind_manuf_cbp reg* [aw=timepwt48] if yr==1990, cluster(statefip)
ivregress 2sls d_sh_empl_nmfg_tm (d_tradeusch_pw l_sh_routine33_nmfg=d_tradeotch_pw_lag R33a_nmfg_1950_90) l_shind_manuf_cbp reg* [aw=timepwt48] if yr==1990, cluster(statefip)


*** TABLE 5: China vs. Routinization, 2000s 

ivregress 2sls d_sh_empl_mfg_ta (d_tradeusch_pw l_sh_routine33_mfg=d_tradeotch_pw_lag R33a_mfg_1950_00) l_shind_manuf_cbp reg* [aw=timepwt48] if yr==2000, cluster(statefip)
ivregress 2sls d_sh_empl_mfg_tr (d_tradeusch_pw l_sh_routine33_mfg=d_tradeotch_pw_lag R33a_mfg_1950_00) l_shind_manuf_cbp reg* [aw=timepwt48] if yr==2000, cluster(statefip)
ivregress 2sls d_sh_empl_mfg_tm (d_tradeusch_pw l_sh_routine33_mfg=d_tradeotch_pw_lag R33a_mfg_1950_00) l_shind_manuf_cbp reg* [aw=timepwt48] if yr==2000, cluster(statefip)

ivregress 2sls d_sh_empl_mfg_ass (d_tradeusch_pw l_sh_routine33_mfg=d_tradeotch_pw_lag R33a_mfg_1950_00) l_shind_manuf_cbp reg* [aw=timepwt48] if yr==2000, cluster(statefip)
ivregress 2sls d_sh_empl_mfg_prod (d_tradeusch_pw l_sh_routine33_mfg=d_tradeotch_pw_lag R33a_mfg_1950_00) l_shind_manuf_cbp reg* [aw=timepwt48] if yr==2000, cluster(statefip)

ivregress 2sls d_sh_empl_nmfg_ta (d_tradeusch_pw l_sh_routine33_nmfg=d_tradeotch_pw_lag R33a_nmfg_1950_00) l_shind_manuf_cbp reg* [aw=timepwt48] if yr==2000, cluster(statefip)
ivregress 2sls d_sh_empl_nmfg_tr (d_tradeusch_pw l_sh_routine33_nmfg=d_tradeotch_pw_lag R33a_nmfg_1950_00) l_shind_manuf_cbp reg* [aw=timepwt48] if yr==2000, cluster(statefip)
ivregress 2sls d_sh_empl_nmfg_tm (d_tradeusch_pw l_sh_routine33_nmfg=d_tradeotch_pw_lag R33a_nmfg_1950_00) l_shind_manuf_cbp reg* [aw=timepwt48] if yr==2000, cluster(statefip)


log close
